# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class RetargetingListServiceTargetingList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'closing_reason': 'RetargetingListServiceClosingReason',
        'default_target_list': 'RetargetingListServiceDefaultTargetList',
        'logical_target_list': 'RetargetingListServiceLogicalTargetList',
        'reach': 'int',
        'reach_storage_span': 'int',
        'reach_storage_status': 'RetargetingListServiceReachStorageStatus',
        'retargeting_account_status': 'RetargetingListServiceRetargetingAccountStatus',
        'rule_base_target_list': 'RetargetingListServiceRuleBaseTargetList',
        'target_list_description': 'str',
        'target_list_id': 'int',
        'target_list_name': 'str',
        'target_list_owner': 'RetargetingListServiceTargetListOwner',
        'target_list_track_id': 'int',
        'target_list_type': 'RetargetingListServiceTargetListType'
    }

    attribute_map = {
        'account_id': 'accountId',
        'closing_reason': 'closingReason',
        'default_target_list': 'defaultTargetList',
        'logical_target_list': 'logicalTargetList',
        'reach': 'reach',
        'reach_storage_span': 'reachStorageSpan',
        'reach_storage_status': 'reachStorageStatus',
        'retargeting_account_status': 'retargetingAccountStatus',
        'rule_base_target_list': 'ruleBaseTargetList',
        'target_list_description': 'targetListDescription',
        'target_list_id': 'targetListId',
        'target_list_name': 'targetListName',
        'target_list_owner': 'targetListOwner',
        'target_list_track_id': 'targetListTrackId',
        'target_list_type': 'targetListType'
    }

    def __init__(self, account_id=None, closing_reason=None, default_target_list=None, logical_target_list=None, reach=None, reach_storage_span=None, reach_storage_status=None, retargeting_account_status=None, rule_base_target_list=None, target_list_description=None, target_list_id=None, target_list_name=None, target_list_owner=None, target_list_track_id=None, target_list_type=None, local_vars_configuration=None):  # noqa: E501
        """RetargetingListServiceTargetingList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._closing_reason = None
        self._default_target_list = None
        self._logical_target_list = None
        self._reach = None
        self._reach_storage_span = None
        self._reach_storage_status = None
        self._retargeting_account_status = None
        self._rule_base_target_list = None
        self._target_list_description = None
        self._target_list_id = None
        self._target_list_name = None
        self._target_list_owner = None
        self._target_list_track_id = None
        self._target_list_type = None
        self.discriminator = None

        self.account_id = account_id
        self.closing_reason = closing_reason
        self.default_target_list = default_target_list
        self.logical_target_list = logical_target_list
        self.reach = reach
        self.reach_storage_span = reach_storage_span
        self.reach_storage_status = reach_storage_status
        self.retargeting_account_status = retargeting_account_status
        self.rule_base_target_list = rule_base_target_list
        self.target_list_description = target_list_description
        self.target_list_id = target_list_id
        self.target_list_name = target_list_name
        self.target_list_owner = target_list_owner
        self.target_list_track_id = target_list_track_id
        self.target_list_type = target_list_type

    @property
    def account_id(self):
        """Gets the account_id of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Account ID.<br>This field is required in any cases.</div>   # noqa: E501

        :return: The account_id of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Account ID.<br>This field is required in any cases.</div>   # noqa: E501

        :param account_id: The account_id of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def closing_reason(self):
        """Gets the closing_reason of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The closing_reason of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceClosingReason
        """
        return self._closing_reason

    @closing_reason.setter
    def closing_reason(self, closing_reason):
        """Sets the closing_reason of this RetargetingListServiceTargetingList.


        :param closing_reason: The closing_reason of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceClosingReason
        """

        self._closing_reason = closing_reason

    @property
    def default_target_list(self):
        """Gets the default_target_list of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The default_target_list of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceDefaultTargetList
        """
        return self._default_target_list

    @default_target_list.setter
    def default_target_list(self, default_target_list):
        """Sets the default_target_list of this RetargetingListServiceTargetingList.


        :param default_target_list: The default_target_list of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceDefaultTargetList
        """

        self._default_target_list = default_target_list

    @property
    def logical_target_list(self):
        """Gets the logical_target_list of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The logical_target_list of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceLogicalTargetList
        """
        return self._logical_target_list

    @logical_target_list.setter
    def logical_target_list(self, logical_target_list):
        """Sets the logical_target_list of this RetargetingListServiceTargetingList.


        :param logical_target_list: The logical_target_list of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceLogicalTargetList
        """

        self._logical_target_list = logical_target_list

    @property
    def reach(self):
        """Gets the reach of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">リストに蓄積されているユーザー数です。</div> <div lang=\"en\">Number of users stored to the list.</div>   # noqa: E501

        :return: The reach of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: int
        """
        return self._reach

    @reach.setter
    def reach(self, reach):
        """Sets the reach of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">リストに蓄積されているユーザー数です。</div> <div lang=\"en\">Number of users stored to the list.</div>   # noqa: E501

        :param reach: The reach of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: int
        """

        self._reach = reach

    @property
    def reach_storage_span(self):
        """Gets the reach_storage_span of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">Cookieを保持する日数です。<br> SET時、このフィールドは省略可能となります。<br>LogicalTargetListの場合、SET時にこのフィールドは無視されます。<br> ※SET時、ruleBaseTargetList.isDateSpecificRule = TRUEの場合には、変更は出来ません。<br> ※Default：180<br> ※1-540日まで設定可能です。</div> <div lang=\"en\">Days to hold Cookie.<br> This field is optional in SET operation.<br> For LogicalTargetList, this field will be ignored in SET operation.<br> *In SET operation, if ruleBaseTargetList.isDateSpecificRule = TRUE, it is can not change.<br> *Default: 180<br> *Can set from 1-540 days.</div>   # noqa: E501

        :return: The reach_storage_span of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: int
        """
        return self._reach_storage_span

    @reach_storage_span.setter
    def reach_storage_span(self, reach_storage_span):
        """Sets the reach_storage_span of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">Cookieを保持する日数です。<br> SET時、このフィールドは省略可能となります。<br>LogicalTargetListの場合、SET時にこのフィールドは無視されます。<br> ※SET時、ruleBaseTargetList.isDateSpecificRule = TRUEの場合には、変更は出来ません。<br> ※Default：180<br> ※1-540日まで設定可能です。</div> <div lang=\"en\">Days to hold Cookie.<br> This field is optional in SET operation.<br> For LogicalTargetList, this field will be ignored in SET operation.<br> *In SET operation, if ruleBaseTargetList.isDateSpecificRule = TRUE, it is can not change.<br> *Default: 180<br> *Can set from 1-540 days.</div>   # noqa: E501

        :param reach_storage_span: The reach_storage_span of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: int
        """

        self._reach_storage_span = reach_storage_span

    @property
    def reach_storage_status(self):
        """Gets the reach_storage_status of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The reach_storage_status of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceReachStorageStatus
        """
        return self._reach_storage_status

    @reach_storage_status.setter
    def reach_storage_status(self, reach_storage_status):
        """Sets the reach_storage_status of this RetargetingListServiceTargetingList.


        :param reach_storage_status: The reach_storage_status of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceReachStorageStatus
        """

        self._reach_storage_status = reach_storage_status

    @property
    def retargeting_account_status(self):
        """Gets the retargeting_account_status of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The retargeting_account_status of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceRetargetingAccountStatus
        """
        return self._retargeting_account_status

    @retargeting_account_status.setter
    def retargeting_account_status(self, retargeting_account_status):
        """Sets the retargeting_account_status of this RetargetingListServiceTargetingList.


        :param retargeting_account_status: The retargeting_account_status of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceRetargetingAccountStatus
        """

        self._retargeting_account_status = retargeting_account_status

    @property
    def rule_base_target_list(self):
        """Gets the rule_base_target_list of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The rule_base_target_list of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceRuleBaseTargetList
        """
        return self._rule_base_target_list

    @rule_base_target_list.setter
    def rule_base_target_list(self, rule_base_target_list):
        """Sets the rule_base_target_list of this RetargetingListServiceTargetingList.


        :param rule_base_target_list: The rule_base_target_list of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceRuleBaseTargetList
        """

        self._rule_base_target_list = rule_base_target_list

    @property
    def target_list_description(self):
        """Gets the target_list_description of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">ターゲットリストの説明です。<br> このフィールドは、いずれの場合でも省略可能となります。</div> <div lang=\"en\">Description of Target List.<br> This field is optional in any cases.</div>   # noqa: E501

        :return: The target_list_description of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: str
        """
        return self._target_list_description

    @target_list_description.setter
    def target_list_description(self, target_list_description):
        """Sets the target_list_description of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">ターゲットリストの説明です。<br> このフィールドは、いずれの場合でも省略可能となります。</div> <div lang=\"en\">Description of Target List.<br> This field is optional in any cases.</div>   # noqa: E501

        :param target_list_description: The target_list_description of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: str
        """

        self._target_list_description = target_list_description

    @property
    def target_list_id(self):
        """Gets the target_list_id of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">ターゲットリストIDです。<br> SET時、このフィールドは必須となります。</div> <div lang=\"en\">Target List ID.<br> This field is required in SET operation.</div>   # noqa: E501

        :return: The target_list_id of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: int
        """
        return self._target_list_id

    @target_list_id.setter
    def target_list_id(self, target_list_id):
        """Sets the target_list_id of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">ターゲットリストIDです。<br> SET時、このフィールドは必須となります。</div> <div lang=\"en\">Target List ID.<br> This field is required in SET operation.</div>   # noqa: E501

        :param target_list_id: The target_list_id of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: int
        """

        self._target_list_id = target_list_id

    @property
    def target_list_name(self):
        """Gets the target_list_name of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">ターゲットリスト名です。<br> ADD時にこのフィールドは必須となり、SET時にこのフィールドは省略可能となります。</div> <div lang=\"en\">Target List name.<br> This field is required in ADD operation, and is optional in SET operation.</div>   # noqa: E501

        :return: The target_list_name of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: str
        """
        return self._target_list_name

    @target_list_name.setter
    def target_list_name(self, target_list_name):
        """Sets the target_list_name of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">ターゲットリスト名です。<br> ADD時にこのフィールドは必須となり、SET時にこのフィールドは省略可能となります。</div> <div lang=\"en\">Target List name.<br> This field is required in ADD operation, and is optional in SET operation.</div>   # noqa: E501

        :param target_list_name: The target_list_name of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: str
        """

        self._target_list_name = target_list_name

    @property
    def target_list_owner(self):
        """Gets the target_list_owner of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The target_list_owner of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceTargetListOwner
        """
        return self._target_list_owner

    @target_list_owner.setter
    def target_list_owner(self, target_list_owner):
        """Sets the target_list_owner of this RetargetingListServiceTargetingList.


        :param target_list_owner: The target_list_owner of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceTargetListOwner
        """

        self._target_list_owner = target_list_owner

    @property
    def target_list_track_id(self):
        """Gets the target_list_track_id of this RetargetingListServiceTargetingList.  # noqa: E501

        <div lang=\"ja\">ターゲットリストのトラッキング用IDです。</div> <div lang=\"en\">Tracking ID of Target list.</div>   # noqa: E501

        :return: The target_list_track_id of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: int
        """
        return self._target_list_track_id

    @target_list_track_id.setter
    def target_list_track_id(self, target_list_track_id):
        """Sets the target_list_track_id of this RetargetingListServiceTargetingList.

        <div lang=\"ja\">ターゲットリストのトラッキング用IDです。</div> <div lang=\"en\">Tracking ID of Target list.</div>   # noqa: E501

        :param target_list_track_id: The target_list_track_id of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: int
        """

        self._target_list_track_id = target_list_track_id

    @property
    def target_list_type(self):
        """Gets the target_list_type of this RetargetingListServiceTargetingList.  # noqa: E501


        :return: The target_list_type of this RetargetingListServiceTargetingList.  # noqa: E501
        :rtype: RetargetingListServiceTargetListType
        """
        return self._target_list_type

    @target_list_type.setter
    def target_list_type(self, target_list_type):
        """Sets the target_list_type of this RetargetingListServiceTargetingList.


        :param target_list_type: The target_list_type of this RetargetingListServiceTargetingList.  # noqa: E501
        :type: RetargetingListServiceTargetListType
        """

        self._target_list_type = target_list_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetargetingListServiceTargetingList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetargetingListServiceTargetingList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class Account(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'account_name': 'str',
        'account_status': 'AccountServiceStatus',
        'account_type': 'AccountServiceType',
        'auto_tagging_enabled': 'AccountServiceAutoTaggingEnabled',
        'delivery_status': 'AccountServiceDeliveryStatus',
        'is_test_account': 'AccountServiceIsTestAccount',
        'start_date': 'str',
        'end_date': 'str',
        'is_mcc_account': 'AccountServiceIsMccAccount',
        'contact_biz_id': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'account_name': 'accountName',
        'account_status': 'accountStatus',
        'account_type': 'accountType',
        'auto_tagging_enabled': 'autoTaggingEnabled',
        'delivery_status': 'deliveryStatus',
        'is_test_account': 'isTestAccount',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'is_mcc_account': 'isMccAccount',
        'contact_biz_id': 'contactBizId'
    }

    def __init__(self, account_id=None, account_name=None, account_status=None, account_type=None, auto_tagging_enabled=None, delivery_status=None, is_test_account=None, start_date=None, end_date=None, is_mcc_account=None, contact_biz_id=None, local_vars_configuration=None):  # noqa: E501
        """Account - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._account_name = None
        self._account_status = None
        self._account_type = None
        self._auto_tagging_enabled = None
        self._delivery_status = None
        self._is_test_account = None
        self._start_date = None
        self._end_date = None
        self._is_mcc_account = None
        self._contact_biz_id = None
        self.discriminator = None

        self.account_id = account_id
        self.account_name = account_name
        self.account_status = account_status
        self.account_type = account_type
        self.auto_tagging_enabled = auto_tagging_enabled
        self.delivery_status = delivery_status
        self.is_test_account = is_test_account
        self.start_date = start_date
        self.end_date = end_date
        self.is_mcc_account = is_mcc_account
        self.contact_biz_id = contact_biz_id

    @property
    def account_id(self):
        """Gets the account_id of this Account.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> SET時、このフィールドは必須となります。</div> <div lang=\"en\">Account ID.<br> This field is required in SET operation.</div>   # noqa: E501

        :return: The account_id of this Account.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Account.

        <div lang=\"ja\">アカウントIDです。<br> SET時、このフィールドは必須となります。</div> <div lang=\"en\">Account ID.<br> This field is required in SET operation.</div>   # noqa: E501

        :param account_id: The account_id of this Account.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def account_name(self):
        """Gets the account_name of this Account.  # noqa: E501

        <div lang=\"ja\">アカウント名です。<br> SET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Account name.<br> This field is optional in SET operation.</div>   # noqa: E501

        :return: The account_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this Account.

        <div lang=\"ja\">アカウント名です。<br> SET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Account name.<br> This field is optional in SET operation.</div>   # noqa: E501

        :param account_name: The account_name of this Account.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def account_status(self):
        """Gets the account_status of this Account.  # noqa: E501


        :return: The account_status of this Account.  # noqa: E501
        :rtype: AccountServiceStatus
        """
        return self._account_status

    @account_status.setter
    def account_status(self, account_status):
        """Sets the account_status of this Account.


        :param account_status: The account_status of this Account.  # noqa: E501
        :type: AccountServiceStatus
        """

        self._account_status = account_status

    @property
    def account_type(self):
        """Gets the account_type of this Account.  # noqa: E501


        :return: The account_type of this Account.  # noqa: E501
        :rtype: AccountServiceType
        """
        return self._account_type

    @account_type.setter
    def account_type(self, account_type):
        """Sets the account_type of this Account.


        :param account_type: The account_type of this Account.  # noqa: E501
        :type: AccountServiceType
        """

        self._account_type = account_type

    @property
    def auto_tagging_enabled(self):
        """Gets the auto_tagging_enabled of this Account.  # noqa: E501


        :return: The auto_tagging_enabled of this Account.  # noqa: E501
        :rtype: AccountServiceAutoTaggingEnabled
        """
        return self._auto_tagging_enabled

    @auto_tagging_enabled.setter
    def auto_tagging_enabled(self, auto_tagging_enabled):
        """Sets the auto_tagging_enabled of this Account.


        :param auto_tagging_enabled: The auto_tagging_enabled of this Account.  # noqa: E501
        :type: AccountServiceAutoTaggingEnabled
        """

        self._auto_tagging_enabled = auto_tagging_enabled

    @property
    def delivery_status(self):
        """Gets the delivery_status of this Account.  # noqa: E501


        :return: The delivery_status of this Account.  # noqa: E501
        :rtype: AccountServiceDeliveryStatus
        """
        return self._delivery_status

    @delivery_status.setter
    def delivery_status(self, delivery_status):
        """Sets the delivery_status of this Account.


        :param delivery_status: The delivery_status of this Account.  # noqa: E501
        :type: AccountServiceDeliveryStatus
        """

        self._delivery_status = delivery_status

    @property
    def is_test_account(self):
        """Gets the is_test_account of this Account.  # noqa: E501


        :return: The is_test_account of this Account.  # noqa: E501
        :rtype: AccountServiceIsTestAccount
        """
        return self._is_test_account

    @is_test_account.setter
    def is_test_account(self, is_test_account):
        """Sets the is_test_account of this Account.


        :param is_test_account: The is_test_account of this Account.  # noqa: E501
        :type: AccountServiceIsTestAccount
        """

        self._is_test_account = is_test_account

    @property
    def start_date(self):
        """Gets the start_date of this Account.  # noqa: E501

        <div lang=\"ja\">掲載開始日です。<br> 「yyyyMMdd」形式で表示されます。<br> SET時、このフィールドは無視されます。</div> <div lang=\"en\">Start date of ad serving.<br> This field will be ignored in SET operation.<br> It is displayed in &#39;yyyyMMdd&#39; format.</div>   # noqa: E501

        :return: The start_date of this Account.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Account.

        <div lang=\"ja\">掲載開始日です。<br> 「yyyyMMdd」形式で表示されます。<br> SET時、このフィールドは無視されます。</div> <div lang=\"en\">Start date of ad serving.<br> This field will be ignored in SET operation.<br> It is displayed in &#39;yyyyMMdd&#39; format.</div>   # noqa: E501

        :param start_date: The start_date of this Account.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Account.  # noqa: E501

        <div lang=\"ja\">掲載終了日です。<br> SET時、このフィールドは無視されます。<br>「yyyyMMdd」形式で表示されます。</div> <div lang=\"en\">End date of ad serving.<br>This field will be ignored in SET operation.<br> It is displayed in &#39;yyyyMMdd&#39; format.</div>   # noqa: E501

        :return: The end_date of this Account.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Account.

        <div lang=\"ja\">掲載終了日です。<br> SET時、このフィールドは無視されます。<br>「yyyyMMdd」形式で表示されます。</div> <div lang=\"en\">End date of ad serving.<br>This field will be ignored in SET operation.<br> It is displayed in &#39;yyyyMMdd&#39; format.</div>   # noqa: E501

        :param end_date: The end_date of this Account.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def is_mcc_account(self):
        """Gets the is_mcc_account of this Account.  # noqa: E501


        :return: The is_mcc_account of this Account.  # noqa: E501
        :rtype: AccountServiceIsMccAccount
        """
        return self._is_mcc_account

    @is_mcc_account.setter
    def is_mcc_account(self, is_mcc_account):
        """Sets the is_mcc_account of this Account.


        :param is_mcc_account: The is_mcc_account of this Account.  # noqa: E501
        :type: AccountServiceIsMccAccount
        """

        self._is_mcc_account = is_mcc_account

    @property
    def contact_biz_id(self):
        """Gets the contact_biz_id of this Account.  # noqa: E501

        <div lang=\"ja\">アカウント管理者のYahoo! JAPANビジネスIDです。<br> MCCアカウントの場合、このフィールドは返却されず、リクエストの際も無視されます。<br> テストアカウントの場合、このフィールドは更新できません。</div> <div lang=\"en\">Contact Business ID.<br> If isManagerAccount is \"TRUE\", this field will not be returned and will be ignored on request.<br> If isTestAccount is \"TRUE\", this field cannot be set.</div>   # noqa: E501

        :return: The contact_biz_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._contact_biz_id

    @contact_biz_id.setter
    def contact_biz_id(self, contact_biz_id):
        """Sets the contact_biz_id of this Account.

        <div lang=\"ja\">アカウント管理者のYahoo! JAPANビジネスIDです。<br> MCCアカウントの場合、このフィールドは返却されず、リクエストの際も無視されます。<br> テストアカウントの場合、このフィールドは更新できません。</div> <div lang=\"en\">Contact Business ID.<br> If isManagerAccount is \"TRUE\", this field will not be returned and will be ignored on request.<br> If isTestAccount is \"TRUE\", this field cannot be set.</div>   # noqa: E501

        :param contact_biz_id: The contact_biz_id of this Account.  # noqa: E501
        :type: str
        """

        self._contact_biz_id = contact_biz_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Account):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignExportServiceExportSetting(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'ad_group_ad_approval_statuses': 'list[CampaignExportServiceApprovalStatus]',
        'ad_group_ad_user_statuses': 'list[CampaignExportServiceUserStatus]',
        'ad_group_criterion_approval_statuses': 'list[CampaignExportServiceApprovalStatus]',
        'ad_group_criterion_ids': 'list[int]',
        'ad_group_criterion_user_statuses': 'list[CampaignExportServiceUserStatus]',
        'ad_group_ids': 'list[int]',
        'ad_group_user_statuses': 'list[CampaignExportServiceUserStatus]',
        'ad_ids': 'list[int]',
        'campaign_criterion_ids': 'list[int]',
        'campaign_ids': 'list[int]',
        'campaign_user_statuses': 'list[CampaignExportServiceUserStatus]',
        'encoding': 'CampaignExportServiceEncoding',
        'entity_types': 'list[CampaignExportServiceEntityType]',
        'export_fields': 'list[str]',
        'job_name': 'str',
        'lang': 'CampaignExportServiceLang',
        'output': 'CampaignExportServiceOutput'
    }

    attribute_map = {
        'account_id': 'accountId',
        'ad_group_ad_approval_statuses': 'adGroupAdApprovalStatuses',
        'ad_group_ad_user_statuses': 'adGroupAdUserStatuses',
        'ad_group_criterion_approval_statuses': 'adGroupCriterionApprovalStatuses',
        'ad_group_criterion_ids': 'adGroupCriterionIds',
        'ad_group_criterion_user_statuses': 'adGroupCriterionUserStatuses',
        'ad_group_ids': 'adGroupIds',
        'ad_group_user_statuses': 'adGroupUserStatuses',
        'ad_ids': 'adIds',
        'campaign_criterion_ids': 'campaignCriterionIds',
        'campaign_ids': 'campaignIds',
        'campaign_user_statuses': 'campaignUserStatuses',
        'encoding': 'encoding',
        'entity_types': 'entityTypes',
        'export_fields': 'exportFields',
        'job_name': 'jobName',
        'lang': 'lang',
        'output': 'output'
    }

    def __init__(self, account_id=None, ad_group_ad_approval_statuses=None, ad_group_ad_user_statuses=None, ad_group_criterion_approval_statuses=None, ad_group_criterion_ids=None, ad_group_criterion_user_statuses=None, ad_group_ids=None, ad_group_user_statuses=None, ad_ids=None, campaign_criterion_ids=None, campaign_ids=None, campaign_user_statuses=None, encoding=None, entity_types=None, export_fields=None, job_name=None, lang=None, output=None, local_vars_configuration=None):  # noqa: E501
        """CampaignExportServiceExportSetting - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._ad_group_ad_approval_statuses = None
        self._ad_group_ad_user_statuses = None
        self._ad_group_criterion_approval_statuses = None
        self._ad_group_criterion_ids = None
        self._ad_group_criterion_user_statuses = None
        self._ad_group_ids = None
        self._ad_group_user_statuses = None
        self._ad_ids = None
        self._campaign_criterion_ids = None
        self._campaign_ids = None
        self._campaign_user_statuses = None
        self._encoding = None
        self._entity_types = None
        self._export_fields = None
        self._job_name = None
        self._lang = None
        self._output = None
        self.discriminator = None

        self.account_id = account_id
        self.ad_group_ad_approval_statuses = ad_group_ad_approval_statuses
        self.ad_group_ad_user_statuses = ad_group_ad_user_statuses
        self.ad_group_criterion_approval_statuses = ad_group_criterion_approval_statuses
        self.ad_group_criterion_ids = ad_group_criterion_ids
        self.ad_group_criterion_user_statuses = ad_group_criterion_user_statuses
        self.ad_group_ids = ad_group_ids
        self.ad_group_user_statuses = ad_group_user_statuses
        self.ad_ids = ad_ids
        self.campaign_criterion_ids = campaign_criterion_ids
        self.campaign_ids = campaign_ids
        self.campaign_user_statuses = campaign_user_statuses
        self.encoding = encoding
        self.entity_types = entity_types
        self.export_fields = export_fields
        self.job_name = job_name
        self.lang = lang
        self.output = output

    @property
    def account_id(self):
        """Gets the account_id of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br>このフィールドは、必須です。</div> <div lang=\"en\">Account ID.<br>This field is required.</div>   # noqa: E501

        :return: The account_id of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">アカウントIDです。<br>このフィールドは、必須です。</div> <div lang=\"en\">Account ID.<br>This field is required.</div>   # noqa: E501

        :param account_id: The account_id of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def ad_group_ad_approval_statuses(self):
        """Gets the ad_group_ad_approval_statuses of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The ad_group_ad_approval_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceApprovalStatus]
        """
        return self._ad_group_ad_approval_statuses

    @ad_group_ad_approval_statuses.setter
    def ad_group_ad_approval_statuses(self, ad_group_ad_approval_statuses):
        """Sets the ad_group_ad_approval_statuses of this CampaignExportServiceExportSetting.


        :param ad_group_ad_approval_statuses: The ad_group_ad_approval_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceApprovalStatus]
        """

        self._ad_group_ad_approval_statuses = ad_group_ad_approval_statuses

    @property
    def ad_group_ad_user_statuses(self):
        """Gets the ad_group_ad_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The ad_group_ad_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceUserStatus]
        """
        return self._ad_group_ad_user_statuses

    @ad_group_ad_user_statuses.setter
    def ad_group_ad_user_statuses(self, ad_group_ad_user_statuses):
        """Sets the ad_group_ad_user_statuses of this CampaignExportServiceExportSetting.


        :param ad_group_ad_user_statuses: The ad_group_ad_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceUserStatus]
        """

        self._ad_group_ad_user_statuses = ad_group_ad_user_statuses

    @property
    def ad_group_criterion_approval_statuses(self):
        """Gets the ad_group_criterion_approval_statuses of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The ad_group_criterion_approval_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceApprovalStatus]
        """
        return self._ad_group_criterion_approval_statuses

    @ad_group_criterion_approval_statuses.setter
    def ad_group_criterion_approval_statuses(self, ad_group_criterion_approval_statuses):
        """Sets the ad_group_criterion_approval_statuses of this CampaignExportServiceExportSetting.


        :param ad_group_criterion_approval_statuses: The ad_group_criterion_approval_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceApprovalStatus]
        """

        self._ad_group_criterion_approval_statuses = ad_group_criterion_approval_statuses

    @property
    def ad_group_criterion_ids(self):
        """Gets the ad_group_criterion_ids of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">広告グループクライテリアIDです。<br>このフィールドは、省略可能となります。</div> <div lang=\"en\">Ad group criteria ID.<br>This field is optional.</div>   # noqa: E501

        :return: The ad_group_criterion_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._ad_group_criterion_ids

    @ad_group_criterion_ids.setter
    def ad_group_criterion_ids(self, ad_group_criterion_ids):
        """Sets the ad_group_criterion_ids of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">広告グループクライテリアIDです。<br>このフィールドは、省略可能となります。</div> <div lang=\"en\">Ad group criteria ID.<br>This field is optional.</div>   # noqa: E501

        :param ad_group_criterion_ids: The ad_group_criterion_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[int]
        """

        self._ad_group_criterion_ids = ad_group_criterion_ids

    @property
    def ad_group_criterion_user_statuses(self):
        """Gets the ad_group_criterion_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The ad_group_criterion_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceUserStatus]
        """
        return self._ad_group_criterion_user_statuses

    @ad_group_criterion_user_statuses.setter
    def ad_group_criterion_user_statuses(self, ad_group_criterion_user_statuses):
        """Sets the ad_group_criterion_user_statuses of this CampaignExportServiceExportSetting.


        :param ad_group_criterion_user_statuses: The ad_group_criterion_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceUserStatus]
        """

        self._ad_group_criterion_user_statuses = ad_group_criterion_user_statuses

    @property
    def ad_group_ids(self):
        """Gets the ad_group_ids of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">ダウンロード対象の広告グループIDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Ad group ID of export objective.<br> This field is optional.</div>   # noqa: E501

        :return: The ad_group_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._ad_group_ids

    @ad_group_ids.setter
    def ad_group_ids(self, ad_group_ids):
        """Sets the ad_group_ids of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">ダウンロード対象の広告グループIDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Ad group ID of export objective.<br> This field is optional.</div>   # noqa: E501

        :param ad_group_ids: The ad_group_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[int]
        """

        self._ad_group_ids = ad_group_ids

    @property
    def ad_group_user_statuses(self):
        """Gets the ad_group_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The ad_group_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceUserStatus]
        """
        return self._ad_group_user_statuses

    @ad_group_user_statuses.setter
    def ad_group_user_statuses(self, ad_group_user_statuses):
        """Sets the ad_group_user_statuses of this CampaignExportServiceExportSetting.


        :param ad_group_user_statuses: The ad_group_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceUserStatus]
        """

        self._ad_group_user_statuses = ad_group_user_statuses

    @property
    def ad_ids(self):
        """Gets the ad_ids of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">ダウンロード対象の広告IDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Ad ID of export objective.<br> This field is optional.</div>   # noqa: E501

        :return: The ad_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._ad_ids

    @ad_ids.setter
    def ad_ids(self, ad_ids):
        """Sets the ad_ids of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">ダウンロード対象の広告IDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Ad ID of export objective.<br> This field is optional.</div>   # noqa: E501

        :param ad_ids: The ad_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[int]
        """

        self._ad_ids = ad_ids

    @property
    def campaign_criterion_ids(self):
        """Gets the campaign_criterion_ids of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">キャンペーンクライテリアIDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Campaign criteria ID.<br> This field is optional.</div>   # noqa: E501

        :return: The campaign_criterion_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._campaign_criterion_ids

    @campaign_criterion_ids.setter
    def campaign_criterion_ids(self, campaign_criterion_ids):
        """Sets the campaign_criterion_ids of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">キャンペーンクライテリアIDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Campaign criteria ID.<br> This field is optional.</div>   # noqa: E501

        :param campaign_criterion_ids: The campaign_criterion_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[int]
        """

        self._campaign_criterion_ids = campaign_criterion_ids

    @property
    def campaign_ids(self):
        """Gets the campaign_ids of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">ダウンロード対象のキャンペーンIDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Campaign ID of export objective.<br> This field is optional.</div>   # noqa: E501

        :return: The campaign_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._campaign_ids

    @campaign_ids.setter
    def campaign_ids(self, campaign_ids):
        """Sets the campaign_ids of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">ダウンロード対象のキャンペーンIDです。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Campaign ID of export objective.<br> This field is optional.</div>   # noqa: E501

        :param campaign_ids: The campaign_ids of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[int]
        """

        self._campaign_ids = campaign_ids

    @property
    def campaign_user_statuses(self):
        """Gets the campaign_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The campaign_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceUserStatus]
        """
        return self._campaign_user_statuses

    @campaign_user_statuses.setter
    def campaign_user_statuses(self, campaign_user_statuses):
        """Sets the campaign_user_statuses of this CampaignExportServiceExportSetting.


        :param campaign_user_statuses: The campaign_user_statuses of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceUserStatus]
        """

        self._campaign_user_statuses = campaign_user_statuses

    @property
    def encoding(self):
        """Gets the encoding of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The encoding of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: CampaignExportServiceEncoding
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this CampaignExportServiceExportSetting.


        :param encoding: The encoding of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: CampaignExportServiceEncoding
        """

        self._encoding = encoding

    @property
    def entity_types(self):
        """Gets the entity_types of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The entity_types of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[CampaignExportServiceEntityType]
        """
        return self._entity_types

    @entity_types.setter
    def entity_types(self, entity_types):
        """Sets the entity_types of this CampaignExportServiceExportSetting.


        :param entity_types: The entity_types of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[CampaignExportServiceEntityType]
        """

        self._entity_types = entity_types

    @property
    def export_fields(self):
        """Gets the export_fields of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">エクスポートするフィールドを指定します。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Select which field to export.<br> This field is optional.</div>   # noqa: E501

        :return: The export_fields of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: list[str]
        """
        return self._export_fields

    @export_fields.setter
    def export_fields(self, export_fields):
        """Sets the export_fields of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">エクスポートするフィールドを指定します。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Select which field to export.<br> This field is optional.</div>   # noqa: E501

        :param export_fields: The export_fields of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: list[str]
        """

        self._export_fields = export_fields

    @property
    def job_name(self):
        """Gets the job_name of this CampaignExportServiceExportSetting.  # noqa: E501

        <div lang=\"ja\">ダウンロードするジョブの名称です。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Job information for export.<br> This field is optional.</div>   # noqa: E501

        :return: The job_name of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this CampaignExportServiceExportSetting.

        <div lang=\"ja\">ダウンロードするジョブの名称です。<br> このフィールドは、省略可能となります。</div> <div lang=\"en\">Job information for export.<br> This field is optional.</div>   # noqa: E501

        :param job_name: The job_name of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def lang(self):
        """Gets the lang of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The lang of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: CampaignExportServiceLang
        """
        return self._lang

    @lang.setter
    def lang(self, lang):
        """Sets the lang of this CampaignExportServiceExportSetting.


        :param lang: The lang of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: CampaignExportServiceLang
        """

        self._lang = lang

    @property
    def output(self):
        """Gets the output of this CampaignExportServiceExportSetting.  # noqa: E501


        :return: The output of this CampaignExportServiceExportSetting.  # noqa: E501
        :rtype: CampaignExportServiceOutput
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this CampaignExportServiceExportSetting.


        :param output: The output of this CampaignExportServiceExportSetting.  # noqa: E501
        :type: CampaignExportServiceOutput
        """

        self._output = output

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignExportServiceExportSetting):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignExportServiceExportSetting):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignServiceBiddingStrategy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bidding_scheme': 'CampaignServiceBiddingScheme',
        'portfolio_bidding_id': 'int',
        'portfolio_bidding_name': 'str',
        'bidding_strategy_source': 'CampaignServiceBiddingStrategySource'
    }

    attribute_map = {
        'bidding_scheme': 'biddingScheme',
        'portfolio_bidding_id': 'portfolioBiddingId',
        'portfolio_bidding_name': 'portfolioBiddingName',
        'bidding_strategy_source': 'biddingStrategySource'
    }

    def __init__(self, bidding_scheme=None, portfolio_bidding_id=None, portfolio_bidding_name=None, bidding_strategy_source=None, local_vars_configuration=None):  # noqa: E501
        """CampaignServiceBiddingStrategy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bidding_scheme = None
        self._portfolio_bidding_id = None
        self._portfolio_bidding_name = None
        self._bidding_strategy_source = None
        self.discriminator = None

        self.bidding_scheme = bidding_scheme
        self.portfolio_bidding_id = portfolio_bidding_id
        self.portfolio_bidding_name = portfolio_bidding_name
        self.bidding_strategy_source = bidding_strategy_source

    @property
    def bidding_scheme(self):
        """Gets the bidding_scheme of this CampaignServiceBiddingStrategy.  # noqa: E501


        :return: The bidding_scheme of this CampaignServiceBiddingStrategy.  # noqa: E501
        :rtype: CampaignServiceBiddingScheme
        """
        return self._bidding_scheme

    @bidding_scheme.setter
    def bidding_scheme(self, bidding_scheme):
        """Sets the bidding_scheme of this CampaignServiceBiddingStrategy.


        :param bidding_scheme: The bidding_scheme of this CampaignServiceBiddingStrategy.  # noqa: E501
        :type: CampaignServiceBiddingScheme
        """

        self._bidding_scheme = bidding_scheme

    @property
    def portfolio_bidding_id(self):
        """Gets the portfolio_bidding_id of this CampaignServiceBiddingStrategy.  # noqa: E501

        <div lang=\"ja\">ポートフォリオ入札IDです。<br> ADD時、標準入札設定の場合、このフィールドは設定不可となり、ポートフォリオ入札設定の場合、必須となります。また、biddingSchemeと同時に設定することはできません。</div> <div lang=\"en\">Portfolio bidding ID.<br> This field cannot be specified when Standard bidding is setting, and is required when Portfolio bidding is setting in ADD operation. It cannot be specified at the same times as biddingScheme.</div>   # noqa: E501

        :return: The portfolio_bidding_id of this CampaignServiceBiddingStrategy.  # noqa: E501
        :rtype: int
        """
        return self._portfolio_bidding_id

    @portfolio_bidding_id.setter
    def portfolio_bidding_id(self, portfolio_bidding_id):
        """Sets the portfolio_bidding_id of this CampaignServiceBiddingStrategy.

        <div lang=\"ja\">ポートフォリオ入札IDです。<br> ADD時、標準入札設定の場合、このフィールドは設定不可となり、ポートフォリオ入札設定の場合、必須となります。また、biddingSchemeと同時に設定することはできません。</div> <div lang=\"en\">Portfolio bidding ID.<br> This field cannot be specified when Standard bidding is setting, and is required when Portfolio bidding is setting in ADD operation. It cannot be specified at the same times as biddingScheme.</div>   # noqa: E501

        :param portfolio_bidding_id: The portfolio_bidding_id of this CampaignServiceBiddingStrategy.  # noqa: E501
        :type: int
        """

        self._portfolio_bidding_id = portfolio_bidding_id

    @property
    def portfolio_bidding_name(self):
        """Gets the portfolio_bidding_name of this CampaignServiceBiddingStrategy.  # noqa: E501

        <div lang=\"ja\">ポートフォリオ入札名です。<br> ADD時、このフィールドは無視されます。<br> ※50文字以内になります。</div> <div lang=\"en\">Portfolio bidding name.<br> This field will be ignored in ADD operation.<br>* Up to 50 characters.</div>   # noqa: E501

        :return: The portfolio_bidding_name of this CampaignServiceBiddingStrategy.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_bidding_name

    @portfolio_bidding_name.setter
    def portfolio_bidding_name(self, portfolio_bidding_name):
        """Sets the portfolio_bidding_name of this CampaignServiceBiddingStrategy.

        <div lang=\"ja\">ポートフォリオ入札名です。<br> ADD時、このフィールドは無視されます。<br> ※50文字以内になります。</div> <div lang=\"en\">Portfolio bidding name.<br> This field will be ignored in ADD operation.<br>* Up to 50 characters.</div>   # noqa: E501

        :param portfolio_bidding_name: The portfolio_bidding_name of this CampaignServiceBiddingStrategy.  # noqa: E501
        :type: str
        """

        self._portfolio_bidding_name = portfolio_bidding_name

    @property
    def bidding_strategy_source(self):
        """Gets the bidding_strategy_source of this CampaignServiceBiddingStrategy.  # noqa: E501


        :return: The bidding_strategy_source of this CampaignServiceBiddingStrategy.  # noqa: E501
        :rtype: CampaignServiceBiddingStrategySource
        """
        return self._bidding_strategy_source

    @bidding_strategy_source.setter
    def bidding_strategy_source(self, bidding_strategy_source):
        """Sets the bidding_strategy_source of this CampaignServiceBiddingStrategy.


        :param bidding_strategy_source: The bidding_strategy_source of this CampaignServiceBiddingStrategy.  # noqa: E501
        :type: CampaignServiceBiddingStrategySource
        """

        self._bidding_strategy_source = bidding_strategy_source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignServiceBiddingStrategy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignServiceBiddingStrategy):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from yahoo_search_api_v12.api.account_customizer_service_api import AccountCustomizerServiceApi
from yahoo_search_api_v12.api.account_link_service_api import AccountLinkServiceApi
from yahoo_search_api_v12.api.account_management_service_api import AccountManagementServiceApi
from yahoo_search_api_v12.api.account_service_api import AccountServiceApi
from yahoo_search_api_v12.api.account_shared_service_api import AccountSharedServiceApi
from yahoo_search_api_v12.api.account_tracking_url_service_api import AccountTrackingUrlServiceApi
from yahoo_search_api_v12.api.ad_group_ad_label_service_api import AdGroupAdLabelServiceApi
from yahoo_search_api_v12.api.ad_group_ad_service_api import AdGroupAdServiceApi
from yahoo_search_api_v12.api.ad_group_asset_service_api import AdGroupAssetServiceApi
from yahoo_search_api_v12.api.ad_group_bid_multiplier_service_api import AdGroupBidMultiplierServiceApi
from yahoo_search_api_v12.api.ad_group_criterion_customizer_service_api import AdGroupCriterionCustomizerServiceApi
from yahoo_search_api_v12.api.ad_group_criterion_label_service_api import AdGroupCriterionLabelServiceApi
from yahoo_search_api_v12.api.ad_group_criterion_service_api import AdGroupCriterionServiceApi
from yahoo_search_api_v12.api.ad_group_customizer_service_api import AdGroupCustomizerServiceApi
from yahoo_search_api_v12.api.ad_group_label_service_api import AdGroupLabelServiceApi
from yahoo_search_api_v12.api.ad_group_retargeting_list_service_api import AdGroupRetargetingListServiceApi
from yahoo_search_api_v12.api.ad_group_service_api import AdGroupServiceApi
from yahoo_search_api_v12.api.ad_group_webpage_service_api import AdGroupWebpageServiceApi
from yahoo_search_api_v12.api.app_link_service_api import AppLinkServiceApi
from yahoo_search_api_v12.api.asset_service_api import AssetServiceApi
from yahoo_search_api_v12.api.audit_log_service_api import AuditLogServiceApi
from yahoo_search_api_v12.api.balance_service_api import BalanceServiceApi
from yahoo_search_api_v12.api.base_account_service_api import BaseAccountServiceApi
from yahoo_search_api_v12.api.bidding_seasonality_adjustment_service_api import BiddingSeasonalityAdjustmentServiceApi
from yahoo_search_api_v12.api.bidding_strategy_service_api import BiddingStrategyServiceApi
from yahoo_search_api_v12.api.budget_order_service_api import BudgetOrderServiceApi
from yahoo_search_api_v12.api.campaign_asset_service_api import CampaignAssetServiceApi
from yahoo_search_api_v12.api.campaign_budget_service_api import CampaignBudgetServiceApi
from yahoo_search_api_v12.api.campaign_criterion_service_api import CampaignCriterionServiceApi
from yahoo_search_api_v12.api.campaign_customizer_service_api import CampaignCustomizerServiceApi
from yahoo_search_api_v12.api.campaign_export_service_api import CampaignExportServiceApi
from yahoo_search_api_v12.api.campaign_label_service_api import CampaignLabelServiceApi
from yahoo_search_api_v12.api.campaign_retargeting_list_service_api import CampaignRetargetingListServiceApi
from yahoo_search_api_v12.api.campaign_service_api import CampaignServiceApi
from yahoo_search_api_v12.api.campaign_shared_set_service_api import CampaignSharedSetServiceApi
from yahoo_search_api_v12.api.campaign_target_service_api import CampaignTargetServiceApi
from yahoo_search_api_v12.api.campaign_webpage_service_api import CampaignWebpageServiceApi
from yahoo_search_api_v12.api.conversion_tracker_service_api import ConversionTrackerServiceApi
from yahoo_search_api_v12.api.customizer_attribute_service_api import CustomizerAttributeServiceApi
from yahoo_search_api_v12.api.dictionary_service_api import DictionaryServiceApi
from yahoo_search_api_v12.api.feed_item_service_api import FeedItemServiceApi
from yahoo_search_api_v12.api.feed_service_api import FeedServiceApi
from yahoo_search_api_v12.api.keyword_forecast_metrics_service_api import KeywordForecastMetricsServiceApi
from yahoo_search_api_v12.api.keyword_plan_idea_service_api import KeywordPlanIdeaServiceApi
from yahoo_search_api_v12.api.label_service_api import LabelServiceApi
from yahoo_search_api_v12.api.offline_conversion_service_api import OfflineConversionServiceApi
from yahoo_search_api_v12.api.page_feed_asset_service_api import PageFeedAssetServiceApi
from yahoo_search_api_v12.api.page_feed_asset_set_service_api import PageFeedAssetSetServiceApi
from yahoo_search_api_v12.api.report_definition_service_api import ReportDefinitionServiceApi
from yahoo_search_api_v12.api.retargeting_list_service_api import RetargetingListServiceApi
from yahoo_search_api_v12.api.shared_criterion_service_api import SharedCriterionServiceApi



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class BiddingSeasonalityAdjustment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'bidding_seasonality_adjustment_name': 'str',
        'description': 'str',
        'bidding_seasonality_adjustment_id': 'int',
        'devices': 'list[BiddingSeasonalityAdjustmentServiceDevices]',
        'start_date_time': 'str',
        'end_date_time': 'str',
        'conversion_rate': 'float',
        'campaign_ids': 'list[int]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'bidding_seasonality_adjustment_name': 'biddingSeasonalityAdjustmentName',
        'description': 'description',
        'bidding_seasonality_adjustment_id': 'biddingSeasonalityAdjustmentId',
        'devices': 'devices',
        'start_date_time': 'startDateTime',
        'end_date_time': 'endDateTime',
        'conversion_rate': 'conversionRate',
        'campaign_ids': 'campaignIds'
    }

    def __init__(self, account_id=None, bidding_seasonality_adjustment_name=None, description=None, bidding_seasonality_adjustment_id=None, devices=None, start_date_time=None, end_date_time=None, conversion_rate=None, campaign_ids=None, local_vars_configuration=None):  # noqa: E501
        """BiddingSeasonalityAdjustment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._bidding_seasonality_adjustment_name = None
        self._description = None
        self._bidding_seasonality_adjustment_id = None
        self._devices = None
        self._start_date_time = None
        self._end_date_time = None
        self._conversion_rate = None
        self._campaign_ids = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        self.bidding_seasonality_adjustment_name = bidding_seasonality_adjustment_name
        self.description = description
        self.bidding_seasonality_adjustment_id = bidding_seasonality_adjustment_id
        self.devices = devices
        self.start_date_time = start_date_time
        self.end_date_time = end_date_time
        self.conversion_rate = conversion_rate
        self.campaign_ids = campaign_ids

    @property
    def account_id(self):
        """Gets the account_id of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def bidding_seasonality_adjustment_name(self):
        """Gets the bidding_seasonality_adjustment_name of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">自動入札のスポット調整名です。<br> ADDおよびSET時、このフィールドは必須となります。<br> ※256文字以内になります。</div> <div lang=\"en\">Bidding seasonality adjustment name.<br> This field is required in ADD and SET operation.<br> *Up to 256 characters.</div>   # noqa: E501

        :return: The bidding_seasonality_adjustment_name of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: str
        """
        return self._bidding_seasonality_adjustment_name

    @bidding_seasonality_adjustment_name.setter
    def bidding_seasonality_adjustment_name(self, bidding_seasonality_adjustment_name):
        """Sets the bidding_seasonality_adjustment_name of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">自動入札のスポット調整名です。<br> ADDおよびSET時、このフィールドは必須となります。<br> ※256文字以内になります。</div> <div lang=\"en\">Bidding seasonality adjustment name.<br> This field is required in ADD and SET operation.<br> *Up to 256 characters.</div>   # noqa: E501

        :param bidding_seasonality_adjustment_name: The bidding_seasonality_adjustment_name of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: str
        """

        self._bidding_seasonality_adjustment_name = bidding_seasonality_adjustment_name

    @property
    def description(self):
        """Gets the description of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">自動入札のスポット調整の説明です。<br> このフィールドは、省略可能となります。<br> ※500文字以内になります。</div> <div lang=\"en\">Bidding Seasonality Adjustment description.<br> This field is optional.<br> *Up to 500 characters.</div>   # noqa: E501

        :return: The description of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">自動入札のスポット調整の説明です。<br> このフィールドは、省略可能となります。<br> ※500文字以内になります。</div> <div lang=\"en\">Bidding Seasonality Adjustment description.<br> This field is optional.<br> *Up to 500 characters.</div>   # noqa: E501

        :param description: The description of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def bidding_seasonality_adjustment_id(self):
        """Gets the bidding_seasonality_adjustment_id of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">自動入札のスポット調整IDです。<br> SET及びREMOVE時、このフィールドは必須です。</div> <div lang=\"en\">Bidding seasonality adjustment ID.<br> This field is required in SET and REMOVE operation.</div>   # noqa: E501

        :return: The bidding_seasonality_adjustment_id of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: int
        """
        return self._bidding_seasonality_adjustment_id

    @bidding_seasonality_adjustment_id.setter
    def bidding_seasonality_adjustment_id(self, bidding_seasonality_adjustment_id):
        """Sets the bidding_seasonality_adjustment_id of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">自動入札のスポット調整IDです。<br> SET及びREMOVE時、このフィールドは必須です。</div> <div lang=\"en\">Bidding seasonality adjustment ID.<br> This field is required in SET and REMOVE operation.</div>   # noqa: E501

        :param bidding_seasonality_adjustment_id: The bidding_seasonality_adjustment_id of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: int
        """

        self._bidding_seasonality_adjustment_id = bidding_seasonality_adjustment_id

    @property
    def devices(self):
        """Gets the devices of this BiddingSeasonalityAdjustment.  # noqa: E501


        :return: The devices of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: list[BiddingSeasonalityAdjustmentServiceDevices]
        """
        return self._devices

    @devices.setter
    def devices(self, devices):
        """Sets the devices of this BiddingSeasonalityAdjustment.


        :param devices: The devices of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: list[BiddingSeasonalityAdjustmentServiceDevices]
        """

        self._devices = devices

    @property
    def start_date_time(self):
        """Gets the start_date_time of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">ルール適用開始日です。<br> ADD時、このフィールドは必須です。<br> ※YYYYMMDDHHmmss形式です。<br> ※リクエスト日は2037/12/30まで 指定可能です。<br> ※startDateTime〜endDateTimeが14日を超える場合はエラーになります。</div> <div lang=\"en\">Start date of rule setting.<br> This field is required in ADD operation.<br> *In YYYYMMDDHHmmss format<br> *Request date can be set up to 2037/12/30<br> *If startDateTime〜endDateTime exceeds 14 days, an error will occur.</div>   # noqa: E501

        :return: The start_date_time of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: str
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">ルール適用開始日です。<br> ADD時、このフィールドは必須です。<br> ※YYYYMMDDHHmmss形式です。<br> ※リクエスト日は2037/12/30まで 指定可能です。<br> ※startDateTime〜endDateTimeが14日を超える場合はエラーになります。</div> <div lang=\"en\">Start date of rule setting.<br> This field is required in ADD operation.<br> *In YYYYMMDDHHmmss format<br> *Request date can be set up to 2037/12/30<br> *If startDateTime〜endDateTime exceeds 14 days, an error will occur.</div>   # noqa: E501

        :param start_date_time: The start_date_time of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: str
        """

        self._start_date_time = start_date_time

    @property
    def end_date_time(self):
        """Gets the end_date_time of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">ルール適用終了日です。<br> ADD時、このフィールドは必須です。<br> ※YYYYMMDDHHmmss形式です。<br> ※リクエスト日は2037/12/30まで 指定可能です。<br> ※startDateTime〜endDateTimeが14日を超える場合はエラーになります。</div> <div lang=\"en\">End date of rule setting.<br> This field is required in ADD operation.<br> *In YYYYMMDDHHmmss format<br> *Request date can be set up to 2037/12/30<br> *If startDateTime〜endDateTime exceeds 14 days, an error will occur.</div>   # noqa: E501

        :return: The end_date_time of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: str
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">ルール適用終了日です。<br> ADD時、このフィールドは必須です。<br> ※YYYYMMDDHHmmss形式です。<br> ※リクエスト日は2037/12/30まで 指定可能です。<br> ※startDateTime〜endDateTimeが14日を超える場合はエラーになります。</div> <div lang=\"en\">End date of rule setting.<br> This field is required in ADD operation.<br> *In YYYYMMDDHHmmss format<br> *Request date can be set up to 2037/12/30<br> *If startDateTime〜endDateTime exceeds 14 days, an error will occur.</div>   # noqa: E501

        :param end_date_time: The end_date_time of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: str
        """

        self._end_date_time = end_date_time

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">コンバージョン率を調整する値です。<br> ADD時、このフィールドは必須となります。<br> ※制限値：0.1 ～ 10 </div> <div lang=\"en\">Value to adjust conversion rate.<br> This field is required in ADD operation.<br> *Range limit: 0.1 ～ 10 </div>   # noqa: E501

        :return: The conversion_rate of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">コンバージョン率を調整する値です。<br> ADD時、このフィールドは必須となります。<br> ※制限値：0.1 ～ 10 </div> <div lang=\"en\">Value to adjust conversion rate.<br> This field is required in ADD operation.<br> *Range limit: 0.1 ～ 10 </div>   # noqa: E501

        :param conversion_rate: The conversion_rate of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def campaign_ids(self):
        """Gets the campaign_ids of this BiddingSeasonalityAdjustment.  # noqa: E501

        <div lang=\"ja\">キャンペーンIDです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in ADD operation.</div>   # noqa: E501

        :return: The campaign_ids of this BiddingSeasonalityAdjustment.  # noqa: E501
        :rtype: list[int]
        """
        return self._campaign_ids

    @campaign_ids.setter
    def campaign_ids(self, campaign_ids):
        """Sets the campaign_ids of this BiddingSeasonalityAdjustment.

        <div lang=\"ja\">キャンペーンIDです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in ADD operation.</div>   # noqa: E501

        :param campaign_ids: The campaign_ids of this BiddingSeasonalityAdjustment.  # noqa: E501
        :type: list[int]
        """

        self._campaign_ids = campaign_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BiddingSeasonalityAdjustment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BiddingSeasonalityAdjustment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'text': 'str',
        'match_type': 'KeywordForecastMetricsServiceMatchType',
        'cpc': 'int',
        'is_negative': 'bool'
    }

    attribute_map = {
        'text': 'text',
        'match_type': 'matchType',
        'cpc': 'cpc',
        'is_negative': 'isNegative'
    }

    def __init__(self, text=None, match_type=None, cpc=None, is_negative=None, local_vars_configuration=None):  # noqa: E501
        """KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._text = None
        self._match_type = None
        self._cpc = None
        self._is_negative = None
        self.discriminator = None

        self.text = text
        self.match_type = match_type
        self.cpc = cpc
        self.is_negative = is_negative

    @property
    def text(self):
        """Gets the text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501

        <div lang=\"ja\">キーワードです。</div> <div lang=\"en\">Keyword.</div>   # noqa: E501

        :return: The text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.

        <div lang=\"ja\">キーワードです。</div> <div lang=\"en\">Keyword.</div>   # noqa: E501

        :param text: The text of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def match_type(self):
        """Gets the match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501


        :return: The match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: KeywordForecastMetricsServiceMatchType
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """Sets the match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.


        :param match_type: The match_type of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: KeywordForecastMetricsServiceMatchType
        """

        self._match_type = match_type

    @property
    def cpc(self):
        """Gets the cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501

        <div lang=\"ja\">最大クリック単価です。<br> isNegativeがTRUEのときにcpcを指定することはできません。</div> <div lang=\"en\">Maximum CPC.<br> When isNegative is TRUE, CPC cannot be specified.</div>   # noqa: E501

        :return: The cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: int
        """
        return self._cpc

    @cpc.setter
    def cpc(self, cpc):
        """Sets the cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.

        <div lang=\"ja\">最大クリック単価です。<br> isNegativeがTRUEのときにcpcを指定することはできません。</div> <div lang=\"en\">Maximum CPC.<br> When isNegative is TRUE, CPC cannot be specified.</div>   # noqa: E501

        :param cpc: The cpc of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: int
        """

        self._cpc = cpc

    @property
    def is_negative(self):
        """Gets the is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501

        <div lang=\"ja\">除外キーワードです。<br> デフォルト値はfalseです。<br> 除外キーワードのみでのリクエストはできません。</div> <div lang=\"en\">Refine keyword.<br> The default value will be FALSE.<br> Cannot request with only refine keyword.</div>   # noqa: E501

        :return: The is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :rtype: bool
        """
        return self._is_negative

    @is_negative.setter
    def is_negative(self, is_negative):
        """Sets the is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.

        <div lang=\"ja\">除外キーワードです。<br> デフォルト値はfalseです。<br> 除外キーワードのみでのリクエストはできません。</div> <div lang=\"en\">Refine keyword.<br> The default value will be FALSE.<br> Cannot request with only refine keyword.</div>   # noqa: E501

        :param is_negative: The is_negative of this KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword.  # noqa: E501
        :type: bool
        """

        self._is_negative = is_negative

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KeywordForecastMetricsServiceKeywordPlanAdGroupKeyword):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class FeedItemServiceLocation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'criterion_type_feed_item': 'FeedItemServiceCriterionTypeFeedItem',
        'geo_restriction': 'FeedItemServiceGeoRestriction',
        'is_remove': 'FeedItemServiceIsRemove',
        'target_id': 'str'
    }

    attribute_map = {
        'criterion_type_feed_item': 'criterionTypeFeedItem',
        'geo_restriction': 'geoRestriction',
        'is_remove': 'isRemove',
        'target_id': 'targetId'
    }

    def __init__(self, criterion_type_feed_item=None, geo_restriction=None, is_remove=None, target_id=None, local_vars_configuration=None):  # noqa: E501
        """FeedItemServiceLocation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._criterion_type_feed_item = None
        self._geo_restriction = None
        self._is_remove = None
        self._target_id = None
        self.discriminator = None

        self.criterion_type_feed_item = criterion_type_feed_item
        self.geo_restriction = geo_restriction
        self.is_remove = is_remove
        self.target_id = target_id

    @property
    def criterion_type_feed_item(self):
        """Gets the criterion_type_feed_item of this FeedItemServiceLocation.  # noqa: E501


        :return: The criterion_type_feed_item of this FeedItemServiceLocation.  # noqa: E501
        :rtype: FeedItemServiceCriterionTypeFeedItem
        """
        return self._criterion_type_feed_item

    @criterion_type_feed_item.setter
    def criterion_type_feed_item(self, criterion_type_feed_item):
        """Sets the criterion_type_feed_item of this FeedItemServiceLocation.


        :param criterion_type_feed_item: The criterion_type_feed_item of this FeedItemServiceLocation.  # noqa: E501
        :type: FeedItemServiceCriterionTypeFeedItem
        """

        self._criterion_type_feed_item = criterion_type_feed_item

    @property
    def geo_restriction(self):
        """Gets the geo_restriction of this FeedItemServiceLocation.  # noqa: E501


        :return: The geo_restriction of this FeedItemServiceLocation.  # noqa: E501
        :rtype: FeedItemServiceGeoRestriction
        """
        return self._geo_restriction

    @geo_restriction.setter
    def geo_restriction(self, geo_restriction):
        """Sets the geo_restriction of this FeedItemServiceLocation.


        :param geo_restriction: The geo_restriction of this FeedItemServiceLocation.  # noqa: E501
        :type: FeedItemServiceGeoRestriction
        """

        self._geo_restriction = geo_restriction

    @property
    def is_remove(self):
        """Gets the is_remove of this FeedItemServiceLocation.  # noqa: E501


        :return: The is_remove of this FeedItemServiceLocation.  # noqa: E501
        :rtype: FeedItemServiceIsRemove
        """
        return self._is_remove

    @is_remove.setter
    def is_remove(self, is_remove):
        """Sets the is_remove of this FeedItemServiceLocation.


        :param is_remove: The is_remove of this FeedItemServiceLocation.  # noqa: E501
        :type: FeedItemServiceIsRemove
        """

        self._is_remove = is_remove

    @property
    def target_id(self):
        """Gets the target_id of this FeedItemServiceLocation.  # noqa: E501

        <div lang=\"ja\">地域種別コードです。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">FeedItemServiceLocation type code.<br> This field is required in ADD operation, is optional in SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :return: The target_id of this FeedItemServiceLocation.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this FeedItemServiceLocation.

        <div lang=\"ja\">地域種別コードです。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">FeedItemServiceLocation type code.<br> This field is required in ADD operation, is optional in SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :param target_id: The target_id of this FeedItemServiceLocation.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedItemServiceLocation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedItemServiceLocation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupCriterion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'ad_group_id': 'int',
        'ad_group_name': 'str',
        'ad_group_track_id': 'int',
        'biddable_ad_group_criterion': 'AdGroupCriterionServiceBiddableAdGroupCriterion',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'campaign_track_id': 'int',
        'criterion': 'AdGroupCriterionServiceCriterion',
        'labels': 'list[AdGroupCriterionServiceLabel]',
        'use': 'AdGroupCriterionServiceUse',
        'trademark_status': 'AdGroupCriterionServiceTrademarkStatus',
        'invalided_trademarks': 'list[str]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'ad_group_id': 'adGroupId',
        'ad_group_name': 'adGroupName',
        'ad_group_track_id': 'adGroupTrackId',
        'biddable_ad_group_criterion': 'biddableAdGroupCriterion',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'campaign_track_id': 'campaignTrackId',
        'criterion': 'criterion',
        'labels': 'labels',
        'use': 'use',
        'trademark_status': 'trademarkStatus',
        'invalided_trademarks': 'invalidedTrademarks'
    }

    def __init__(self, account_id=None, ad_group_id=None, ad_group_name=None, ad_group_track_id=None, biddable_ad_group_criterion=None, campaign_id=None, campaign_name=None, campaign_track_id=None, criterion=None, labels=None, use=None, trademark_status=None, invalided_trademarks=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupCriterion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._ad_group_id = None
        self._ad_group_name = None
        self._ad_group_track_id = None
        self._biddable_ad_group_criterion = None
        self._campaign_id = None
        self._campaign_name = None
        self._campaign_track_id = None
        self._criterion = None
        self._labels = None
        self._use = None
        self._trademark_status = None
        self._invalided_trademarks = None
        self.discriminator = None

        self.account_id = account_id
        self.ad_group_id = ad_group_id
        self.ad_group_name = ad_group_name
        self.ad_group_track_id = ad_group_track_id
        self.biddable_ad_group_criterion = biddable_ad_group_criterion
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.campaign_track_id = campaign_track_id
        self.criterion = criterion
        self.labels = labels
        self.use = use
        self.trademark_status = trademark_status
        self.invalided_trademarks = invalided_trademarks

    @property
    def account_id(self):
        """Gets the account_id of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this AdGroupCriterion.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AdGroupCriterion.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this AdGroupCriterion.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def ad_group_id(self):
        """Gets the ad_group_id of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">広告グループIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Ad group ID.<br> This field is required in any cases.</div>   # noqa: E501

        :return: The ad_group_id of this AdGroupCriterion.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_id

    @ad_group_id.setter
    def ad_group_id(self, ad_group_id):
        """Sets the ad_group_id of this AdGroupCriterion.

        <div lang=\"ja\">広告グループIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Ad group ID.<br> This field is required in any cases.</div>   # noqa: E501

        :param ad_group_id: The ad_group_id of this AdGroupCriterion.  # noqa: E501
        :type: int
        """

        self._ad_group_id = ad_group_id

    @property
    def ad_group_name(self):
        """Gets the ad_group_name of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">広告グループ名です。</div> <div lang=\"en\">Ad group name.</div>   # noqa: E501

        :return: The ad_group_name of this AdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_name

    @ad_group_name.setter
    def ad_group_name(self, ad_group_name):
        """Sets the ad_group_name of this AdGroupCriterion.

        <div lang=\"ja\">広告グループ名です。</div> <div lang=\"en\">Ad group name.</div>   # noqa: E501

        :param ad_group_name: The ad_group_name of this AdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._ad_group_name = ad_group_name

    @property
    def ad_group_track_id(self):
        """Gets the ad_group_track_id of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">トラッキング用広告グループIDです。</div> <div lang=\"en\">Ad group ID for tracking.</div>   # noqa: E501

        :return: The ad_group_track_id of this AdGroupCriterion.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_track_id

    @ad_group_track_id.setter
    def ad_group_track_id(self, ad_group_track_id):
        """Sets the ad_group_track_id of this AdGroupCriterion.

        <div lang=\"ja\">トラッキング用広告グループIDです。</div> <div lang=\"en\">Ad group ID for tracking.</div>   # noqa: E501

        :param ad_group_track_id: The ad_group_track_id of this AdGroupCriterion.  # noqa: E501
        :type: int
        """

        self._ad_group_track_id = ad_group_track_id

    @property
    def biddable_ad_group_criterion(self):
        """Gets the biddable_ad_group_criterion of this AdGroupCriterion.  # noqa: E501


        :return: The biddable_ad_group_criterion of this AdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceBiddableAdGroupCriterion
        """
        return self._biddable_ad_group_criterion

    @biddable_ad_group_criterion.setter
    def biddable_ad_group_criterion(self, biddable_ad_group_criterion):
        """Sets the biddable_ad_group_criterion of this AdGroupCriterion.


        :param biddable_ad_group_criterion: The biddable_ad_group_criterion of this AdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceBiddableAdGroupCriterion
        """

        self._biddable_ad_group_criterion = biddable_ad_group_criterion

    @property
    def campaign_id(self):
        """Gets the campaign_id of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">キャンペーンIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in any cases.</div>   # noqa: E501

        :return: The campaign_id of this AdGroupCriterion.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this AdGroupCriterion.

        <div lang=\"ja\">キャンペーンIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in any cases.</div>   # noqa: E501

        :param campaign_id: The campaign_id of this AdGroupCriterion.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">キャンペーン名です。</div> <div lang=\"en\">Campaign name.</div>   # noqa: E501

        :return: The campaign_name of this AdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this AdGroupCriterion.

        <div lang=\"ja\">キャンペーン名です。</div> <div lang=\"en\">Campaign name.</div>   # noqa: E501

        :param campaign_name: The campaign_name of this AdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def campaign_track_id(self):
        """Gets the campaign_track_id of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">トラッキング用キャンペーンIDです。</div> <div lang=\"en\">Campaign ID for tracking.</div>   # noqa: E501

        :return: The campaign_track_id of this AdGroupCriterion.  # noqa: E501
        :rtype: int
        """
        return self._campaign_track_id

    @campaign_track_id.setter
    def campaign_track_id(self, campaign_track_id):
        """Sets the campaign_track_id of this AdGroupCriterion.

        <div lang=\"ja\">トラッキング用キャンペーンIDです。</div> <div lang=\"en\">Campaign ID for tracking.</div>   # noqa: E501

        :param campaign_track_id: The campaign_track_id of this AdGroupCriterion.  # noqa: E501
        :type: int
        """

        self._campaign_track_id = campaign_track_id

    @property
    def criterion(self):
        """Gets the criterion of this AdGroupCriterion.  # noqa: E501


        :return: The criterion of this AdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceCriterion
        """
        return self._criterion

    @criterion.setter
    def criterion(self, criterion):
        """Sets the criterion of this AdGroupCriterion.


        :param criterion: The criterion of this AdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceCriterion
        """

        self._criterion = criterion

    @property
    def labels(self):
        """Gets the labels of this AdGroupCriterion.  # noqa: E501


        :return: The labels of this AdGroupCriterion.  # noqa: E501
        :rtype: list[AdGroupCriterionServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AdGroupCriterion.


        :param labels: The labels of this AdGroupCriterion.  # noqa: E501
        :type: list[AdGroupCriterionServiceLabel]
        """

        self._labels = labels

    @property
    def use(self):
        """Gets the use of this AdGroupCriterion.  # noqa: E501


        :return: The use of this AdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceUse
        """
        return self._use

    @use.setter
    def use(self, use):
        """Sets the use of this AdGroupCriterion.


        :param use: The use of this AdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceUse
        """

        self._use = use

    @property
    def trademark_status(self):
        """Gets the trademark_status of this AdGroupCriterion.  # noqa: E501


        :return: The trademark_status of this AdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceTrademarkStatus
        """
        return self._trademark_status

    @trademark_status.setter
    def trademark_status(self, trademark_status):
        """Sets the trademark_status of this AdGroupCriterion.


        :param trademark_status: The trademark_status of this AdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceTrademarkStatus
        """

        self._trademark_status = trademark_status

    @property
    def invalided_trademarks(self):
        """Gets the invalided_trademarks of this AdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">制限された商標です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">Invalided trademarks.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The invalided_trademarks of this AdGroupCriterion.  # noqa: E501
        :rtype: list[str]
        """
        return self._invalided_trademarks

    @invalided_trademarks.setter
    def invalided_trademarks(self, invalided_trademarks):
        """Sets the invalided_trademarks of this AdGroupCriterion.

        <div lang=\"ja\">制限された商標です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">Invalided trademarks.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param invalided_trademarks: The invalided_trademarks of this AdGroupCriterion.  # noqa: E501
        :type: list[str]
        """

        self._invalided_trademarks = invalided_trademarks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupCriterion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupCriterion):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignServiceBudget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'amount': 'int',
        'campaign_budget_id': 'int',
        'campaign_budget_name': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'campaign_budget_id': 'campaignBudgetId',
        'campaign_budget_name': 'campaignBudgetName'
    }

    def __init__(self, amount=None, campaign_budget_id=None, campaign_budget_name=None, local_vars_configuration=None):  # noqa: E501
        """CampaignServiceBudget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._amount = None
        self._campaign_budget_id = None
        self._campaign_budget_name = None
        self.discriminator = None

        self.amount = amount
        self.campaign_budget_id = campaign_budget_id
        self.campaign_budget_name = campaign_budget_name

    @property
    def amount(self):
        """Gets the amount of this CampaignServiceBudget.  # noqa: E501

        <div lang=\"ja\">1日単位のキャンペーン予算利用金額です。<br> ADDおよびSET時、個別予算を設定する場合、このフィールドは必須となり、共有予算を設定する場合、設定不可となります。また、campaignBudgetIdと同時に設定することはできません。</div> <div lang=\"en\">Amount of budget of Campaign.<br> In ADD and SET operation, this field is required when setting individual budgets, and is not allowed when setting shared budgets. This field cannot be set at the same time as campaignBudgetId.</div>   # noqa: E501

        :return: The amount of this CampaignServiceBudget.  # noqa: E501
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CampaignServiceBudget.

        <div lang=\"ja\">1日単位のキャンペーン予算利用金額です。<br> ADDおよびSET時、個別予算を設定する場合、このフィールドは必須となり、共有予算を設定する場合、設定不可となります。また、campaignBudgetIdと同時に設定することはできません。</div> <div lang=\"en\">Amount of budget of Campaign.<br> In ADD and SET operation, this field is required when setting individual budgets, and is not allowed when setting shared budgets. This field cannot be set at the same time as campaignBudgetId.</div>   # noqa: E501

        :param amount: The amount of this CampaignServiceBudget.  # noqa: E501
        :type: int
        """

        self._amount = amount

    @property
    def campaign_budget_id(self):
        """Gets the campaign_budget_id of this CampaignServiceBudget.  # noqa: E501

        <div lang=\"ja\">共有予算IDです。<br> ※現在、こちらのフィールドは利用できません。<br> ADDおよびSET時、個別予算を設定する場合、このフィールドは設定不可となり、共有予算を設定する場合、必須となります。また、amountと同時に設定することはできません。</div> <div lang=\"en\">CampaignBudget ID.<br> *Currently this field is not available.<br> In ADD and SET operation, this field is not allowed when setting individual budgets, and is required when setting shared budgets. This field cannot be set at the same time as amount.</div>   # noqa: E501

        :return: The campaign_budget_id of this CampaignServiceBudget.  # noqa: E501
        :rtype: int
        """
        return self._campaign_budget_id

    @campaign_budget_id.setter
    def campaign_budget_id(self, campaign_budget_id):
        """Sets the campaign_budget_id of this CampaignServiceBudget.

        <div lang=\"ja\">共有予算IDです。<br> ※現在、こちらのフィールドは利用できません。<br> ADDおよびSET時、個別予算を設定する場合、このフィールドは設定不可となり、共有予算を設定する場合、必須となります。また、amountと同時に設定することはできません。</div> <div lang=\"en\">CampaignBudget ID.<br> *Currently this field is not available.<br> In ADD and SET operation, this field is not allowed when setting individual budgets, and is required when setting shared budgets. This field cannot be set at the same time as amount.</div>   # noqa: E501

        :param campaign_budget_id: The campaign_budget_id of this CampaignServiceBudget.  # noqa: E501
        :type: int
        """

        self._campaign_budget_id = campaign_budget_id

    @property
    def campaign_budget_name(self):
        """Gets the campaign_budget_name of this CampaignServiceBudget.  # noqa: E501

        <div lang=\"ja\">共有予算名です。<br> ※現在、こちらのフィールドは利用できません。<br> ADDおよびSET時、このフィールドは無視されます。</div> <div lang=\"en\">CampaignBudget name.<br> *Currently this field is not available.<br> This field will be ignored in ADD and SET operation.</div>   # noqa: E501

        :return: The campaign_budget_name of this CampaignServiceBudget.  # noqa: E501
        :rtype: str
        """
        return self._campaign_budget_name

    @campaign_budget_name.setter
    def campaign_budget_name(self, campaign_budget_name):
        """Sets the campaign_budget_name of this CampaignServiceBudget.

        <div lang=\"ja\">共有予算名です。<br> ※現在、こちらのフィールドは利用できません。<br> ADDおよびSET時、このフィールドは無視されます。</div> <div lang=\"en\">CampaignBudget name.<br> *Currently this field is not available.<br> This field will be ignored in ADD and SET operation.</div>   # noqa: E501

        :param campaign_budget_name: The campaign_budget_name of this CampaignServiceBudget.  # noqa: E501
        :type: str
        """

        self._campaign_budget_name = campaign_budget_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignServiceBudget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignServiceBudget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupWebpageServiceWebpage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parameter': 'AdGroupWebpageServiceWebpageParameter',
        'target_id': 'int',
        'target_track_id': 'int'
    }

    attribute_map = {
        'parameter': 'parameter',
        'target_id': 'targetId',
        'target_track_id': 'targetTrackId'
    }

    def __init__(self, parameter=None, target_id=None, target_track_id=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupWebpageServiceWebpage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._parameter = None
        self._target_id = None
        self._target_track_id = None
        self.discriminator = None

        self.parameter = parameter
        self.target_id = target_id
        self.target_track_id = target_track_id

    @property
    def parameter(self):
        """Gets the parameter of this AdGroupWebpageServiceWebpage.  # noqa: E501


        :return: The parameter of this AdGroupWebpageServiceWebpage.  # noqa: E501
        :rtype: AdGroupWebpageServiceWebpageParameter
        """
        return self._parameter

    @parameter.setter
    def parameter(self, parameter):
        """Sets the parameter of this AdGroupWebpageServiceWebpage.


        :param parameter: The parameter of this AdGroupWebpageServiceWebpage.  # noqa: E501
        :type: AdGroupWebpageServiceWebpageParameter
        """

        self._parameter = parameter

    @property
    def target_id(self):
        """Gets the target_id of this AdGroupWebpageServiceWebpage.  # noqa: E501

        <div lang=\"ja\">AdGroupWebpageServiceWebpageを識別するIDです。<br>このフィールドは、ADD時は無視され、SET時は必須となります。</div> <div lang=\"en\">Unique ID for each identify webpage.<br>This field will be ignored in ADD operation, and is required in SET operation.</div>   # noqa: E501

        :return: The target_id of this AdGroupWebpageServiceWebpage.  # noqa: E501
        :rtype: int
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this AdGroupWebpageServiceWebpage.

        <div lang=\"ja\">AdGroupWebpageServiceWebpageを識別するIDです。<br>このフィールドは、ADD時は無視され、SET時は必須となります。</div> <div lang=\"en\">Unique ID for each identify webpage.<br>This field will be ignored in ADD operation, and is required in SET operation.</div>   # noqa: E501

        :param target_id: The target_id of this AdGroupWebpageServiceWebpage.  # noqa: E501
        :type: int
        """

        self._target_id = target_id

    @property
    def target_track_id(self):
        """Gets the target_track_id of this AdGroupWebpageServiceWebpage.  # noqa: E501

        <div lang=\"ja\">AdGroupWebpageServiceWebpageを識別するトラッキングIDです。<br>このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Tracking ID for each identify webpage.<br>Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The target_track_id of this AdGroupWebpageServiceWebpage.  # noqa: E501
        :rtype: int
        """
        return self._target_track_id

    @target_track_id.setter
    def target_track_id(self, target_track_id):
        """Sets the target_track_id of this AdGroupWebpageServiceWebpage.

        <div lang=\"ja\">AdGroupWebpageServiceWebpageを識別するトラッキングIDです。<br>このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Tracking ID for each identify webpage.<br>Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param target_track_id: The target_track_id of this AdGroupWebpageServiceWebpage.  # noqa: E501
        :type: int
        """

        self._target_track_id = target_track_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupWebpageServiceWebpage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupWebpageServiceWebpage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class ConversionTrackerServiceSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'app_ids': 'list[str]',
        'categories': 'list[ConversionTrackerServiceCategory]',
        'conversion_counting_types': 'list[ConversionTrackerServiceConversionCountingType]',
        'conversion_date_range': 'ConversionTrackerServiceConversionDateRange',
        'conversion_tracker_ids': 'list[int]',
        'conversion_tracker_types': 'list[ConversionTrackerServiceConversionTrackerType]',
        'exclude_from_biddings': 'list[ConversionTrackerServiceExcludeFromBidding]',
        'number_results': 'int',
        'start_index': 'int',
        'statuses': 'list[ConversionTrackerServiceStatus]',
        'tracking_code_types': 'list[ConversionTrackerServiceTrackingCodeType]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'app_ids': 'appIds',
        'categories': 'categories',
        'conversion_counting_types': 'conversionCountingTypes',
        'conversion_date_range': 'conversionDateRange',
        'conversion_tracker_ids': 'conversionTrackerIds',
        'conversion_tracker_types': 'conversionTrackerTypes',
        'exclude_from_biddings': 'excludeFromBiddings',
        'number_results': 'numberResults',
        'start_index': 'startIndex',
        'statuses': 'statuses',
        'tracking_code_types': 'trackingCodeTypes'
    }

    def __init__(self, account_id=None, app_ids=None, categories=None, conversion_counting_types=None, conversion_date_range=None, conversion_tracker_ids=None, conversion_tracker_types=None, exclude_from_biddings=None, number_results=500, start_index=1, statuses=None, tracking_code_types=None, local_vars_configuration=None):  # noqa: E501
        """ConversionTrackerServiceSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._app_ids = None
        self._categories = None
        self._conversion_counting_types = None
        self._conversion_date_range = None
        self._conversion_tracker_ids = None
        self._conversion_tracker_types = None
        self._exclude_from_biddings = None
        self._number_results = None
        self._start_index = None
        self._statuses = None
        self._tracking_code_types = None
        self.discriminator = None

        self.account_id = account_id
        self.app_ids = app_ids
        self.categories = categories
        self.conversion_counting_types = conversion_counting_types
        self.conversion_date_range = conversion_date_range
        self.conversion_tracker_ids = conversion_tracker_ids
        self.conversion_tracker_types = conversion_tracker_types
        self.exclude_from_biddings = exclude_from_biddings
        self.number_results = number_results
        self.start_index = start_index
        self.statuses = statuses
        self.tracking_code_types = tracking_code_types

    @property
    def account_id(self):
        """Gets the account_id of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def app_ids(self):
        """Gets the app_ids of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">アプリケーションIDです。</div> <div lang=\"en\">App ID.</div>   # noqa: E501

        :return: The app_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[str]
        """
        return self._app_ids

    @app_ids.setter
    def app_ids(self, app_ids):
        """Sets the app_ids of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">アプリケーションIDです。</div> <div lang=\"en\">App ID.</div>   # noqa: E501

        :param app_ids: The app_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[str]
        """

        self._app_ids = app_ids

    @property
    def categories(self):
        """Gets the categories of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The categories of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceCategory]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ConversionTrackerServiceSelector.


        :param categories: The categories of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceCategory]
        """

        self._categories = categories

    @property
    def conversion_counting_types(self):
        """Gets the conversion_counting_types of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The conversion_counting_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceConversionCountingType]
        """
        return self._conversion_counting_types

    @conversion_counting_types.setter
    def conversion_counting_types(self, conversion_counting_types):
        """Sets the conversion_counting_types of this ConversionTrackerServiceSelector.


        :param conversion_counting_types: The conversion_counting_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceConversionCountingType]
        """

        self._conversion_counting_types = conversion_counting_types

    @property
    def conversion_date_range(self):
        """Gets the conversion_date_range of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The conversion_date_range of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: ConversionTrackerServiceConversionDateRange
        """
        return self._conversion_date_range

    @conversion_date_range.setter
    def conversion_date_range(self, conversion_date_range):
        """Sets the conversion_date_range of this ConversionTrackerServiceSelector.


        :param conversion_date_range: The conversion_date_range of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: ConversionTrackerServiceConversionDateRange
        """

        self._conversion_date_range = conversion_date_range

    @property
    def conversion_tracker_ids(self):
        """Gets the conversion_tracker_ids of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">コンバージョントラッカーIDです。</div> <div lang=\"en\">Conversion Tracker ID.</div>   # noqa: E501

        :return: The conversion_tracker_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[int]
        """
        return self._conversion_tracker_ids

    @conversion_tracker_ids.setter
    def conversion_tracker_ids(self, conversion_tracker_ids):
        """Sets the conversion_tracker_ids of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">コンバージョントラッカーIDです。</div> <div lang=\"en\">Conversion Tracker ID.</div>   # noqa: E501

        :param conversion_tracker_ids: The conversion_tracker_ids of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[int]
        """

        self._conversion_tracker_ids = conversion_tracker_ids

    @property
    def conversion_tracker_types(self):
        """Gets the conversion_tracker_types of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The conversion_tracker_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceConversionTrackerType]
        """
        return self._conversion_tracker_types

    @conversion_tracker_types.setter
    def conversion_tracker_types(self, conversion_tracker_types):
        """Sets the conversion_tracker_types of this ConversionTrackerServiceSelector.


        :param conversion_tracker_types: The conversion_tracker_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceConversionTrackerType]
        """

        self._conversion_tracker_types = conversion_tracker_types

    @property
    def exclude_from_biddings(self):
        """Gets the exclude_from_biddings of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The exclude_from_biddings of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceExcludeFromBidding]
        """
        return self._exclude_from_biddings

    @exclude_from_biddings.setter
    def exclude_from_biddings(self, exclude_from_biddings):
        """Sets the exclude_from_biddings of this ConversionTrackerServiceSelector.


        :param exclude_from_biddings: The exclude_from_biddings of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceExcludeFromBidding]
        """

        self._exclude_from_biddings = exclude_from_biddings

    @property
    def number_results(self):
        """Gets the number_results of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1. Also see Entity Limits per operation.</div>   # noqa: E501

        :return: The number_results of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._number_results

    @number_results.setter
    def number_results(self, number_results):
        """Sets the number_results of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1. Also see Entity Limits per operation.</div>   # noqa: E501

        :param number_results: The number_results of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results > 500):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value less than or equal to `500`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results < 1):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value greater than or equal to `1`")  # noqa: E501

        self._number_results = number_results

    @property
    def start_index(self):
        """Gets the start_index of this ConversionTrackerServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :return: The start_index of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this ConversionTrackerServiceSelector.

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :param start_index: The start_index of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                start_index is not None and start_index < 1):  # noqa: E501
            raise ValueError("Invalid value for `start_index`, must be a value greater than or equal to `1`")  # noqa: E501

        self._start_index = start_index

    @property
    def statuses(self):
        """Gets the statuses of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The statuses of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceStatus]
        """
        return self._statuses

    @statuses.setter
    def statuses(self, statuses):
        """Sets the statuses of this ConversionTrackerServiceSelector.


        :param statuses: The statuses of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceStatus]
        """

        self._statuses = statuses

    @property
    def tracking_code_types(self):
        """Gets the tracking_code_types of this ConversionTrackerServiceSelector.  # noqa: E501


        :return: The tracking_code_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :rtype: list[ConversionTrackerServiceTrackingCodeType]
        """
        return self._tracking_code_types

    @tracking_code_types.setter
    def tracking_code_types(self, tracking_code_types):
        """Sets the tracking_code_types of this ConversionTrackerServiceSelector.


        :param tracking_code_types: The tracking_code_types of this ConversionTrackerServiceSelector.  # noqa: E501
        :type: list[ConversionTrackerServiceTrackingCodeType]
        """

        self._tracking_code_types = tracking_code_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversionTrackerServiceSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConversionTrackerServiceSelector):
            return True

        return self.to_dict() != other.to_dict()
